PCB Environment: NavRasterizeParams Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
NavRasterizeParams Struct Reference

`#include <NavPoint.hpp>`

## Public Member Functions
bool | isNoop () const

## Data Fields
Real | Expansion {0.0}
uint16_t | IgnoreMask {0}
| Expand shapes outward by this amount (ignored with AutoExpand).
uint16_t | FlagsAnd {0xffff}
| Skip all operations for points with hasFlags(IgnoreMask).
uint16_t | FlagsOr {0}
| Clear flags not set here (may remove CLEARANCE).
uint16_t | WriteSeq
| Set these flags (after FlagsAnd).
bool | AutoExpand {false}
| Used to prevent writing overlapping points of track segments/joints twice.
bool | AutoIncrementWriteSeq {true}
| Whether to rasterize the track & via clearance areas (assumes KOCount.Tracks != 0).
NavKeepoutCounts | KOCount
int8_t | TrackRasterCount {0}
| Added to NavPoint's counts to determine CLEARANCE flags.

## Detailed Description

This class contains parameters for updating the NavGrid's costs and flags when rasterizing shapes. Note that the CLEARANCE flags are updated even if the KO counts are 0.

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavPoint.hpp